==> docusign-esign-java-5.0.0-sources.jar: com/docusign/esign/model/BulkSendRequest.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.util.Objects;

/**
 * This object contains information about the envelope or template that you want to send in bulk..
 */
@Schema(
    description =
        "This object contains information about the envelope or template that you want to send in bulk.")
public class BulkSendRequest {
  @JsonProperty("batchName")
  private String batchName = null;

  @JsonProperty("envelopeOrTemplateId")
  private String envelopeOrTemplateId = null;

  /**
   * batchName.
   *
   * @return BulkSendRequest
   */
  public BulkSendRequest batchName(String batchName) {
    this.batchName = batchName;
    return this;
  }

  /**
   * .
   *
   * @return batchName
   */
  @Schema(description = "")
  public String getBatchName() {
    return batchName;
  }

  /** setBatchName. */
  public void setBatchName(String batchName) {
    this.batchName = batchName;
  }

  /**
   * envelopeOrTemplateId.
   *
   * @return BulkSendRequest
   */
  public BulkSendRequest envelopeOrTemplateId(String envelopeOrTemplateId) {
    this.envelopeOrTemplateId = envelopeOrTemplateId;
    return this;
  }

  /**
   * .
   *
   * @return envelopeOrTemplateId
   */
  @Schema(description = "")
  public String getEnvelopeOrTemplateId() {
    return envelopeOrTemplateId;
  }

  /** setEnvelopeOrTemplateId. */
  public void setEnvelopeOrTemplateId(String envelopeOrTemplateId) {
    this.envelopeOrTemplateId = envelopeOrTemplateId;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BulkSendRequest bulkSendRequest = (BulkSendRequest) o;
    return Objects.equals(this.batchName, bulkSendRequest.batchName)
        && Objects.equals(this.envelopeOrTemplateId, bulkSendRequest.envelopeOrTemplateId);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(batchName, envelopeOrTemplateId);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BulkSendRequest {\n");

    sb.append("    batchName: ").append(toIndentedString(batchName)).append("\n");
    sb.append("    envelopeOrTemplateId: ")
        .append(toIndentedString(envelopeOrTemplateId))
        .append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> docusign-esign-java-6.4.0-sources.jar: com/docusign/esign/model/BulkSendRequest.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.util.Objects;

/**
 * This object contains information about the envelope or template that you want to send in bulk..
 */
@Schema(
    description =
        "This object contains information about the envelope or template that you want to send in bulk.")
public class BulkSendRequest implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("batchName")
  private String batchName = null;

  @JsonProperty("envelopeOrTemplateId")
  private String envelopeOrTemplateId = null;

  /**
   * batchName.
   *
   * @return BulkSendRequest
   */
  public BulkSendRequest batchName(String batchName) {
    this.batchName = batchName;
    return this;
  }

  /**
   * .
   *
   * @return batchName
   */
  @Schema(description = "")
  public String getBatchName() {
    return batchName;
  }

  /** setBatchName. */
  public void setBatchName(String batchName) {
    this.batchName = batchName;
  }

  /**
   * envelopeOrTemplateId.
   *
   * @return BulkSendRequest
   */
  public BulkSendRequest envelopeOrTemplateId(String envelopeOrTemplateId) {
    this.envelopeOrTemplateId = envelopeOrTemplateId;
    return this;
  }

  /**
   * .
   *
   * @return envelopeOrTemplateId
   */
  @Schema(description = "")
  public String getEnvelopeOrTemplateId() {
    return envelopeOrTemplateId;
  }

  /** setEnvelopeOrTemplateId. */
  public void setEnvelopeOrTemplateId(String envelopeOrTemplateId) {
    this.envelopeOrTemplateId = envelopeOrTemplateId;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BulkSendRequest bulkSendRequest = (BulkSendRequest) o;
    return Objects.equals(this.batchName, bulkSendRequest.batchName)
        && Objects.equals(this.envelopeOrTemplateId, bulkSendRequest.envelopeOrTemplateId);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(batchName, envelopeOrTemplateId);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BulkSendRequest {\n");

    sb.append("    batchName: ").append(toIndentedString(batchName)).append("\n");
    sb.append("    envelopeOrTemplateId: ")
        .append(toIndentedString(envelopeOrTemplateId))
        .append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
